@@ -29,13 +29,13 @@ DEFAULT_SUCCESS_CODE = [200, 201]
 def requests_decorator(method=METHOD_GET, success_code=200, stop_code=None, failure_skip=True, max_retry=3, timeout=30):
     def external_wrapper(function):
         def internal_wrapper(*args, **kwargs):
-            _method = kwargs.pop("method")
+            _method = kwargs.pop("method", None)
             if not _method:
                 _method = method
             _method = _method.upper()
             if _method != METHOD_GET and _method != METHOD_POST and _method != METHOD_PUT and _method != METHOD_DELETE:
                 raise ValueError(str(_method) + "  request mode is not supported")
-            data = kwargs.pop("data")
+            data = kwargs.pop("data", None)
             if data:
                 if not isinstance(data, str):
                     raise ValueError("  data type must bu str")
@@ -53,11 +53,11 @@ def requests_decorator(method=METHOD_GET, success_code=200, stop_code=None, fail
                     response = requests.request(_method, url, timeout=timeout, **kwargs)
 
                     if any(
-                        [
-                            response.status_code == success_code,
-                            response.status_code in DEFAULT_SUCCESS_CODE,
-                            response.status_code in _stop_code,
-                        ]
+                            [
+                                response.status_code == success_code,
+                                response.status_code in DEFAULT_SUCCESS_CODE,
+                                response.status_code in _stop_code,
+                            ]
                     ):
                         break
                 except ConnectionError as e:
