@@ -161,11 +161,14 @@ class ESClient(BaseArgsParsing):
                 body = self.build(body, "query.bool.must.bool.should.match_phrase", key, value)
         return body
 
-    def search(self, body, index, page=1, size=20):
-        from_ = (page - 1) * size
-        if page * size > 10000:
-            raise ValueError(f"'page'*'size'不能大于10000，当前 {page * size}")
-        results = self.es.search(body=body, index=index, size=size, from_=from_)
+    def search(self, body, index, page=1, size=20, all_result=False):
+        if all_result:
+            results = self.es.search(body=body, index=index, size=10000)
+        else:
+            from_ = (page - 1) * size
+            if page * size > 10000:
+                raise ValueError(f"'page'*'size'不能大于10000，当前 {page * size}")
+            results = self.es.search(body=body, index=index, size=size, from_=from_)
         return results
 
     def to_results(self, es_results, page, size, results: Results = None):
